autowisp.database.data_model.processing_sequence module — AutoWISP documentation

# autowisp.database.data_model.processing_sequence module

## Class Inheritance Diagram

Define the class that sets the processing order of step/image type.

class autowisp.database.data_model.processing_sequence.ProcessingSequence(**kwargs)

  Bases: `DataModelBase`

  The sequence of steps/image type to be processed by the pipeline.

  id

    A unique identifier for each row.

  image_type
  image_type_id

    The image type to be processed by the step.

  step
  step_id

    The step to be executed.

  timestamp

    When record was last changed